@@ -85,7 +85,7 @@ export PKG_CONFIG_PATH="$inst/lib/pkgconfig:$PKG_CONFIG_PATH"
 export LD_LIBRARY_PATH="$inst/lib"
 export PATH="$inst/bin:$PATH"
 
-CONFIG="--enable-sanitize --enable-werror --with-uhd --with-usrp1 --with-lms --with-ipc $INSTR"
+CONFIG="--enable-sanitize --enable-werror --with-uhd --with-usrp1 --with-lms --with-ipc --with-mstrx $INSTR"
 
 # Additional configure options and depends
 if [ "$WITH_MANUALS" = "1" ]; then
@@ -101,13 +101,17 @@ echo
 set -x
 
 cd "$base"
+git submodule status
 autoreconf --install --force
 ./configure $CONFIG
 $MAKE $PARALLEL_MAKE
 $MAKE check \
   || cat-testlogs.sh
-DISTCHECK_CONFIGURE_FLAGS="$CONFIG" $MAKE $PARALLEL_MAKE distcheck \
-  || cat-testlogs.sh
+
+if arch | grep -v -q arm; then
+	DISTCHECK_CONFIGURE_FLAGS="$CONFIG" $MAKE $PARALLEL_MAKE distcheck \
+	  || cat-testlogs.sh
+fi
 
 if [ "$WITH_MANUALS" = "1" ] && [ "$PUBLISH" = "1" ]; then
 	make -C "$base/doc/manuals" publish
@@ -115,9 +119,4 @@ fi
 
 $MAKE $PARALLEL_MAKE maintainer-clean
 
-# Verify distro-specific package patches apply:
-for patch in debian/patches/*.patch; do
-        patch --dry-run -p1 < "$patch"
-done
-
 osmo-clean-workspace.sh
