@@ -6,16 +6,13 @@
 #include <osmocom/vty/buffer.h>
 #include <osmocom/vty/command.h>
 
+#include <osmocom/bb/common/vty.h>
+
 enum ms_vty_node {
-	MS_NODE = _LAST_OSMOVTY_NODE + 1,
-	TESTSIM_NODE,
-	SUPPORT_NODE,
+	SUPPORT_NODE = _LAST_L23VTY_NODE + 1,
 	AUDIO_NODE,
 };
 
-int ms_vty_go_parent(struct vty *vty);
 int ms_vty_init(void);
-extern void vty_notify(struct osmocom_ms *ms, const char *fmt, ...) __attribute__ ((format (printf, 2, 3)));
-
 #endif
 
