@@ -37,44 +37,20 @@
 #include <osmocom/gsm/protocol/gsm_04_08.h>
 #include <osmocom/gsm/protocol/gsm_08_58.h>
 #include <osmocom/gsm/rsl.h>
+#include <osmocom/gsm/lapdm.h>
+#include <osmocom/gsm/gsm0502.h>
 
 #include <osmocom/bb/common/l1ctl.h>
+#include <osmocom/bb/common/l23_app.h>
 #include <osmocom/bb/common/osmocom_data.h>
+#include <osmocom/bb/common/ms.h>
 #include <osmocom/bb/common/l1l2_interface.h>
-#include <osmocom/gsm/lapdm.h>
 #include <osmocom/bb/common/logging.h>
 
-extern struct gsmtap_inst *gsmtap_inst;
-
-#define CB_FCCH		-1
-#define CB_SCH		-2
-#define CB_BCCH		-3
-#define CB_IDLE		-4
-
-/* according to TS 05.02 Clause 7 Table 3 of 9 an Figure 8a */
-static const int ccch_block_table[51] = {
-	CB_FCCH, CB_SCH,/* 0..1 */
-	CB_BCCH, CB_BCCH, CB_BCCH, CB_BCCH,	/* 2..5: BCCH */
-	0, 0, 0, 0,	/* 6..9: B0 */
-	CB_FCCH, CB_SCH,/* 10..11 */
-	1, 1, 1, 1,	/* 12..15: B1 */
-	2, 2, 2, 2,	/* 16..19: B2 */
-	CB_FCCH, CB_SCH,/* 20..21 */
-	3, 3, 3, 3,	/* 22..25: B3 */
-	4, 4, 4, 4,	/* 26..29: B4 */
-	CB_FCCH, CB_SCH,/* 30..31 */
-	5, 5, 5, 5,	/* 32..35: B5 */
-	6, 6, 6, 6,	/* 36..39: B6 */
-	CB_FCCH, CB_SCH,/* 40..41 */
-	7, 7, 7, 7, 	/* 42..45: B7 */
-	8, 8, 8, 8, 	/* 46..49: B8 */
-	-4		/* 50: Idle */
-};
-
 /* determine the CCCH block number based on the frame number */
 static unsigned int fn2ccch_block(uint32_t fn)
 {
-	int rc = ccch_block_table[fn%51];
+	int rc = gsm0502_fn2ccch_block(fn);
 	/* if FN is negative, we were called for something that's not CCCH! */
 	OSMO_ASSERT(rc >= 0);
 	return rc;
@@ -316,7 +292,7 @@ static int rx_ph_data_ind(struct osmocom_ms *ms, struct msgb *msg)
 	 * to clog up your logs */
 	if (!is_fill_frame(gsmtap_chan_type, ccch->data)) {
 		/* send CCCH data via GSMTAP */
-		gsmtap_send(gsmtap_inst, ntohs(dl->band_arfcn), chan_ts,
+		gsmtap_send(l23_cfg.gsmtap.inst, ntohs(dl->band_arfcn), chan_ts,
 			    gsmtap_chan_type, chan_ss, tm.fn, dl->rx_level-110,
 			    dl->snr, ccch->data, sizeof(ccch->data));
 	}
@@ -341,6 +317,7 @@ static int rx_ph_data_ind(struct osmocom_ms *ms, struct msgb *msg)
 			PRIM_OP_INDICATION, msg);
 	pp.u.data.chan_nr = dl->chan_nr;
 	pp.u.data.link_id = dl->link_id;
+	pp.u.data.fn = tm.fn;
 
 	/* send it up into LAPDm */
 	return lapdm_phsap_up(&pp.oph, le);
@@ -393,8 +370,8 @@ int l1ctl_tx_data_req(struct osmocom_ms *ms, struct msgb *msg,
 	/* send copy via GSMTAP */
 	if (rsl_dec_chan_nr(chan_nr, &chan_type, &chan_ss, &chan_ts) == 0) {
 		uint8_t gsmtap_chan_type = chantype_rsl2gsmtap2(chan_type, link_id, false);
-		gsmtap_send(gsmtap_inst, ms->rrlayer.cd_now.arfcn | GSMTAP_ARFCN_F_UPLINK,
-			    chan_ts, gsmtap_chan_type, chan_ss, 0, 127, 255,
+		gsmtap_send(l23_cfg.gsmtap.inst, ms->rrlayer.cd_now.arfcn | GSMTAP_ARFCN_F_UPLINK,
+			    chan_ts, gsmtap_chan_type, chan_ss, 0, 127, 0,
 			    msg->l2h, msgb_l2len(msg));
 	} else {
 		LOGP(DL1C, LOGL_ERROR,
@@ -736,10 +713,7 @@ int l1ctl_tx_sim_req(struct osmocom_ms *ms, uint8_t *data, uint16_t length)
 /* just forward the SIM response to the SIM handler */
 static int rx_l1_sim_conf(struct osmocom_ms *ms, struct msgb *msg)
 {
-	uint16_t len = msgb_l2len(msg);
-	uint8_t *data = msg->data;
-
-	LOGP(DL1C, LOGL_INFO, "SIM %s\n", osmo_hexdump(data, len));
+	LOGP(DL1C, LOGL_INFO, "SIM %s\n", msgb_hexdump_l1(msg));
 
 	sim_apdu_resp(ms, msg);
 
@@ -981,6 +955,141 @@ static int rx_l1_neigh_pm_ind(struct osmocom_ms *ms, struct msgb *msg)
 	return 0;
 }
 
+/* Receive L1CTL_GPRS_DL_BLOCK_IND */
+static int rx_l1_gprs_dl_block_ind(struct osmocom_ms *ms, struct msgb *msg)
+{
+	const struct l1ctl_gprs_dl_block_ind *ind = (void *)msg->l1h;
+
+	if (msgb_l1len(msg) < sizeof(*ind)) {
+		LOGP(DL1C, LOGL_ERROR,
+		     "Rx malformed GPRS DL BLOCK.ind (len=%u < %zu)\n",
+		     msgb_l1len(msg), sizeof(*ind));
+		return -EINVAL;
+	}
+	if (OSMO_UNLIKELY(ind->hdr.tn >= 8)) {
+		LOGP(DL1C, LOGL_ERROR,
+		     "Rx malformed GPRS DL BLOCK.ind (tn=%u)\n",
+		     ind->hdr.tn);
+		return -EINVAL;
+	}
+
+	msg->l2h = (void *)&ind->data[0];
+
+	DEBUGP(DL1C, "Rx GPRS DL block (fn=%u, tn=%u, len=%u): %s\n",
+	       ntohl(ind->hdr.fn), ind->hdr.tn, msgb_l2len(msg), msgb_hexdump_l2(msg));
+
+	/* distribute or drop */
+	if (ms->l1_entity.l1_gprs_dl_block_ind)
+		return ms->l1_entity.l1_gprs_dl_block_ind(ms, msg);
+
+	msgb_free(msg);
+	return 0;
+}
+
+/* Receive L1CTL_GPRS_RTS_IND */
+static int rx_l1_gprs_rts_ind(struct osmocom_ms *ms, struct msgb *msg)
+{
+	const struct l1ctl_gprs_rts_ind *ind = (void *)msg->l1h;
+
+	if (msgb_l1len(msg) < sizeof(*ind)) {
+		LOGP(DL1C, LOGL_ERROR,
+		     "Rx malformed GPRS RTS.ind (len=%u < %zu)\n",
+		     msgb_l1len(msg), sizeof(*ind));
+		return -EINVAL;
+	}
+	if (OSMO_UNLIKELY(ind->tn >= 8)) {
+		LOGP(DL1C, LOGL_ERROR,
+		     "Rx malformed GPRS RTS.ind (tn=%u)\n",
+		     ind->tn);
+		return -EINVAL;
+	}
+
+	DEBUGP(DL1C, "Rx RTS.ind (fn=%u, tn=%u, usf=%u)\n",
+	       ntohl(ind->fn), ind->tn, ind->usf);
+
+	/* distribute or drop */
+	if (ms->l1_entity.l1_gprs_rts_ind)
+		return ms->l1_entity.l1_gprs_rts_ind(ms, msg);
+
+	msgb_free(msg);
+	return 0;
+}
+
+/* Transmit L1CTL_GPRS_UL_BLOCK_REQ */
+int l1ctl_tx_gprs_ul_block_req(struct osmocom_ms *ms, uint32_t fn, uint8_t tn,
+			       const uint8_t *data, size_t data_len)
+{
+	struct l1ctl_gprs_ul_block_req *req;
+	struct msgb *msg;
+
+	msg = osmo_l1_alloc(L1CTL_GPRS_UL_BLOCK_REQ);
+	if (!msg)
+		return -ENOMEM;
+
+	req = (void *)msgb_put(msg, sizeof(*req));
+	req->hdr.fn = htonl(fn);
+	req->hdr.tn = tn;
+	if (data_len > 0)
+		memcpy(msgb_put(msg, data_len), data, data_len);
+
+	DEBUGP(DL1C, "Tx GPRS UL block (fn=%u, tn=%u, len=%zu): %s\n",
+	       fn, tn, data_len, osmo_hexdump(data, data_len));
+
+	return osmo_send_l1(ms, msg);
+}
+
+/* Transmit L1CTL_GPRS_UL_TBF_CFG_REQ */
+int l1ctl_tx_gprs_ul_tbf_cfg_req(struct osmocom_ms *ms, uint8_t tbf_ref,
+				 uint8_t slotmask, uint32_t start_fn)
+{
+	struct l1ctl_gprs_ul_tbf_cfg_req *req;
+	struct msgb *msg;
+
+	msg = osmo_l1_alloc(L1CTL_GPRS_UL_TBF_CFG_REQ);
+	if (!msg)
+		return -ENOMEM;
+
+	req = (void *)msgb_put(msg, sizeof(*req));
+	*req = (struct l1ctl_gprs_ul_tbf_cfg_req) {
+		.tbf_ref = tbf_ref,
+		.slotmask = slotmask,
+		.start_fn = htonl(start_fn),
+	};
+
+	DEBUGP(DL1C, "Tx GPRS UL TBF CFG: "
+	       "tbf_ref=%u, slotmask=0x%02x, start_fn=%u\n",
+	       tbf_ref, slotmask, start_fn);
+
+	return osmo_send_l1(ms, msg);
+}
+
+/* Transmit L1CTL_GPRS_DL_TBF_CFG_REQ */
+int l1ctl_tx_gprs_dl_tbf_cfg_req(struct osmocom_ms *ms, uint8_t tbf_ref,
+				 uint8_t slotmask, uint32_t start_fn,
+				 uint8_t dl_tfi)
+{
+	struct l1ctl_gprs_dl_tbf_cfg_req *req;
+	struct msgb *msg;
+
+	msg = osmo_l1_alloc(L1CTL_GPRS_DL_TBF_CFG_REQ);
+	if (!msg)
+		return -ENOMEM;
+
+	req = (void *)msgb_put(msg, sizeof(*req));
+	*req = (struct l1ctl_gprs_dl_tbf_cfg_req) {
+		.tbf_ref = tbf_ref,
+		.slotmask = slotmask,
+		.start_fn = htonl(start_fn),
+		.dl_tfi = dl_tfi,
+	};
+
+	DEBUGP(DL1C, "Tx GPRS DL TBF CFG: "
+	       "tbf_ref=%u, slotmask=0x%02x, start_fn=%u, dl_tfi=%u)\n",
+	       tbf_ref, slotmask, start_fn, dl_tfi);
+
+	return osmo_send_l1(ms, msg);
+}
+
 /* Receive incoming data from L1 using L1CTL format */
 int l1ctl_recv(struct osmocom_ms *ms, struct msgb *msg)
 {
@@ -1049,6 +1158,12 @@ int l1ctl_recv(struct osmocom_ms *ms, struct msgb *msg)
 	case L1CTL_TRAFFIC_CONF:
 		msgb_free(msg);
 		break;
+	case L1CTL_GPRS_DL_BLOCK_IND:
+		rc = rx_l1_gprs_dl_block_ind(ms, msg);
+		break;
+	case L1CTL_GPRS_RTS_IND:
+		rc = rx_l1_gprs_rts_ind(ms, msg);
+		break;
 	default:
 		LOGP(DL1C, LOGL_ERROR, "Unknown MSG: %u\n", hdr->msg_type);
 		msgb_free(msg);
