@@ -28,6 +28,7 @@
 
 #include <osmocom/bb/common/logging.h>
 #include <osmocom/bb/common/osmocom_data.h>
+#include <osmocom/bb/common/ms.h>
 #include <osmocom/bb/mobile/mncc.h>
 #include <osmocom/bb/mobile/transaction.h>
 #include <osmocom/bb/mobile/gsm48_cc.h>
@@ -51,7 +52,7 @@ int gsm48_cc_init(struct osmocom_ms *ms)
 
 	cc->ms = ms;
 
-	if (!cc->mncc_upqueue.next == 0)
+	if (cc->mncc_upqueue.next != NULL)
 		return 0;
 
 	LOGP(DCC, LOGL_INFO, "init Call Control\n");
